@@ -27,7 +27,6 @@
 
 #[macro_use] extern crate log;
 extern crate rustc_hash;
-#[macro_use] extern crate try_or;
 extern crate failure;
 #[macro_use] extern crate failure_derive;
 extern crate walkdir;
@@ -273,15 +272,17 @@ fn use_token_default<T : DataObject + 'static>() -> RefCell<Option<PackageUseTok
     RefCell::new(None)
 }
 
-/// A path to a data resource, resolvable to a cached [DataId]. This object serves three purposes:
+/// A path to a data resource, resolvable to a cached [DataId].
+///
+/// This object serves three purposes:
 ///
 /// - Conveniently resolving a path to an ID but only when resolution is necessary
 /// - Serializing data that needs to reference a DataObject
 /// - Keeping a package open so it doesn't get auto-unloaded.
 ///
 /// If placing inside a DataObject struct, take care not to have a self-referencing type
-///  (i.e. a DataHandle<T> inside a T) or a type cycle
-///  (i.e. a DataHandle<T> inside a U and a DataHandle<U> inside a T). Otherwise the auto-unload
+///  (i.e. a DataHandle\<T\> inside a T) or a type cycle
+///  (i.e. a DataHandle\<T\> inside a U and a DataHandle\<U\> inside a T). Otherwise the auto-unload
 ///  mechanism may not be able to unload the package the object is from.
 #[cfg_attr(feature = "serde", derive(Serialize, Deserialize))]
 pub struct DataHandle<T : DataObject + 'static>
@@ -581,7 +582,7 @@ pub trait DataObject
     fn want_file(pathname : &str) -> bool where Self : Sized;
     /// A constructor that returns a new [DataObject] of this type given a path and a [Source] object.
     fn from_package_source(source : &mut Box<dyn Source>, package_name : &str, pathname : &str) -> Result<Self, DataError> where Self : Sized;
-    /// A function that writes to the given [Write] object to save its data
+    /// A function that writes the object to the given [Source] to save its data
     #[allow(unused_variables)]
     fn write(&mut self, package_name : &str, pathname : &str, source : &mut Box<dyn Source>) -> Result<(), DataError> { Err(DataError::NotSupported) }
     /// Implement this to support "generations" for detecting when the data for a given path is changed.
@@ -671,8 +672,7 @@ impl<T : DataObject + 'static> DataStore<T>
 
             for entry in iter
             {
-                let pathname = try_or_else!(entry,
-                    |error| Err(DataError::PackageSourceError(error)));
+                let pathname = entry.map_err(|error| DataError::PackageSourceError(error))?;
 
                 if pathname.starts_with('/') || pathname.ends_with('/')
                 {
@@ -892,7 +892,8 @@ impl<T : DataObject + 'static> DataStore<T>
     ///  not be invalidated. Returns true if the package was loaded.
     pub fn unload_all(&mut self)
     {
-        self.unload_all_internal()
+        self.unload_all_internal();
+        info!("Unloaded all packages for \"{}\"", T::folder_name());
     }
 
     /// Unloads all packages that do not have an active [PackageUseToken].
@@ -917,10 +918,12 @@ impl<T : DataObject + 'static> DataStore<T>
     /// Saves the indicated item using the [Source] given by [SourceId].
     pub fn save(&mut self, package_name : &str, pathname : &str, source_id : SourceId) -> Result<(), DataError>
     {
-        let id = try_or_else!(self.get_id_mut(package_name, pathname),
-            |error| Err(error));
-        let data = try_opt_or_else!(&mut self.data_list[id.index],
-            || Err(DataError::DataNotFound));
+        let id = self.get_id_mut(package_name, pathname)?;
+        let data = match &mut self.data_list[id.index]
+        {
+            Some(data) => { data }
+            None => { return Err(DataError::DataNotFound); }
+        };
 
         if let Some(source) = self.source_manager.borrow_mut().source(source_id)
         {
@@ -967,7 +970,7 @@ impl<T : DataObject + 'static> DataStore<T>
     /// Reloads an already-loaded resource by the given name.
     pub fn reload(&mut self, package_name : &str, pathname : &str) -> Result<(), DataError>
     {
-        let id = try_or_else!(self.get_id_mut(package_name, pathname), |error| Err(error));
+        let id = self.get_id_mut(package_name, pathname)?;
 
         if let Some(mut source) = self.source_manager.borrow_mut().package_source(package_name)
         {
@@ -1082,8 +1085,6 @@ impl<T : DataObject + 'static> DataStoreBase for DataStore<T>
 
         self.data_map.clear();
         self.data_list.clear();
-
-        info!("Unloaded all packages for \"{}\"", T::folder_name());
     }
 }
 
@@ -1271,6 +1272,8 @@ impl DataMultistore
         {
             self.stores[index].borrow_mut().unload_all_internal();
         }
+
+        info!("Unloaded all packages");
     }
 
     /// Unloads all packages that do not have an active [PackageUseToken].
