@@ -116,7 +116,7 @@ pub enum PackageError
     /// A package item's path does not belong to the package's path.
     #[fail(display = "Package item does not belong to the given prefix: {}", _0)]
     PrefixMismatch(StripPrefixError),
-    /// The package has no [DataObject] by the given pathname
+    /// The package has no [crate::DataObject] by the given pathname
     #[fail(display = "The data object was not found")]
     DataNotFound,
     /// The operation is not supported by this implementation
@@ -207,19 +207,22 @@ impl Iterator for FilesystemIter
     {
         while let Some(dir_next) = self.walkdir.next()
         {
-            let dir_entry = try_or_else!(dir_next,
-                |error : walkdir::Error|
+            let dir_entry = match dir_next
             {
-                if let Some(io_error) = error.io_error()
+                Ok(dir_entry) => { dir_entry }
+                Err(error) =>
                 {
-                    if io_error.kind() == std::io::ErrorKind::NotFound
+                    if let Some(io_error) = error.io_error()
                     {
-                        return None;
+                        if io_error.kind() == std::io::ErrorKind::NotFound
+                        {
+                            return None;
+                        }
                     }
-                }
 
-                Some(Err(PackageError::IoError(error.into())))
-            });
+                    return Some(Err(PackageError::IoError(error.into())));
+                }
+            };
 
             if !dir_entry.file_type().is_file()
             {
@@ -227,8 +230,14 @@ impl Iterator for FilesystemIter
             }
 
             let path = dir_entry.path();
-            let filepath = try_or_else!(path.strip_prefix(self.basepath.clone()),
-                |error| Some(Err(PackageError::PrefixMismatch(error))));
+            let filepath = match path.strip_prefix(self.basepath.clone())
+            {
+                Ok(filepath) => { filepath }
+                Err(error) =>
+                {
+                    return Some(Err(PackageError::PrefixMismatch(error)));
+                }
+            };
 
             let mut pathname = String::new();
             let mut first_part = true;
@@ -326,8 +335,8 @@ impl Source for FilesystemSource
         let mut path = PathBuf::from(&self.basedir);
         path.push(format!("{}/{}", package_name, pathname));
 
-        let file = BufReader::new(try_or_else!(File::open(path),
-            |error| Err(PackageError::IoError(error))));
+        let file = BufReader::new(File::open(path).map_err(
+            |error| PackageError::IoError(error))?);
 
         Ok(Box::new(file))
     }
@@ -343,11 +352,11 @@ impl Source for FilesystemSource
             folder_path.pop();
         }
 
-        try_or_else!(std::fs::create_dir_all(folder_path),
-            |error| Err(PackageError::IoError(error)));
+        std::fs::create_dir_all(folder_path).map_err(
+            |error| PackageError::IoError(error))?;
 
-        let file = BufWriter::new(try_or_else!(File::create(path),
-            |error| Err(PackageError::IoError(error))));
+        let file = BufWriter::new(File::create(path).map_err(
+            |error| PackageError::IoError(error))?);
 
         Ok(Box::new(file))
     }
@@ -509,11 +518,11 @@ impl ZipFolderSource
         zip_name.push_str(&self.extension);
         path.push(zip_name);
 
-        let file = BufReader::new(try_or_else!(File::open(path),
-            |error| Err(PackageError::IoError(error))));
+        let file = BufReader::new(File::open(path).map_err(
+            |error| PackageError::IoError(error))?);
 
-        let archive = try_or_else!(ZipArchive::new(file),
-            |error| Err(package_error_for_zip_error(error)));
+        let archive = ZipArchive::new(file).map_err(
+            |error| package_error_for_zip_error(error))?;
 
         self.loaded_zips.insert(package_name.to_string(), archive);
 
